@@ -22,27 +22,10 @@
 
 #include <libglom/connectionpool_backends/postgres_central.h>
 #include <glibmm/i18n.h>
-#include <bakery/bakery.h>
 
 // Uncomment to see debug messages
 //#define GLOM_CONNECTION_DEBUG
 
-namespace
-{
-
-static Glib::ustring port_as_string(int port_num)
-{
-  Glib::ustring result;
-  char* cresult = g_strdup_printf("%d", port_num);
-  if(cresult)
-    result = cresult;
-  g_free(cresult);
-
-  return result;
-}
-
-}
-
 namespace Glom
 {
 
@@ -50,9 +33,7 @@ namespace ConnectionPoolBackends
 {
 
 PostgresCentralHosted::PostgresCentralHosted()
-:
-  m_port(0),
-  m_try_other_ports(true)
+: m_try_other_ports(true)
 {
   m_list_ports.push_back("5432"); //Ubuntu Breezy seems to default to this for Postgres 7.4, and this is probably the default for most postgres installations, including Fedora.
 
@@ -75,7 +56,7 @@ void PostgresCentralHosted::set_host(const Glib::ustring& value)
   }
 }
 
-void PostgresCentralHosted::set_port(int port)
+void PostgresCentralHosted::set_port(unsigned int port)
 {
   m_port = port;
 }
@@ -90,7 +71,7 @@ Glib::ustring PostgresCentralHosted::get_host() const
   return m_host;
 }
 
-int PostgresCentralHosted::get_port() const
+unsigned int PostgresCentralHosted::get_port() const
 {
   return m_port;
 }
@@ -100,7 +81,7 @@ bool PostgresCentralHosted::get_try_other_ports() const
   return m_try_other_ports;
 }
 
-Glib::RefPtr<Gnome::Gda::Connection> PostgresCentralHosted::connect(const Glib::ustring& database, const Glib::ustring& username, const Glib::ustring& password, std::auto_ptr<ExceptionConnection>& error)
+Glib::RefPtr<Gnome::Gda::Connection> PostgresCentralHosted::connect(const Glib::ustring& database, const Glib::ustring& username, const Glib::ustring& password)
 {
   Glib::RefPtr<Gnome::Gda::Connection> connection;
 
@@ -112,15 +93,23 @@ Glib::RefPtr<Gnome::Gda::Connection> PostgresCentralHosted::connect(const Glib::
   if(m_port == 0)
     port = *iter_port ++;
 
-  connection = attempt_connect(m_host, port, database, username, password, error);
-
-  // Remember port if only the database was missing
   bool connection_possible = false;
-  if(error.get() && error->get_failure_type() == ExceptionConnection::FAILURE_NO_DATABASE)
+  try
   {
+    connection = attempt_connect(port, database, username, password);
     connection_possible = true;
     m_port = atoi(port.c_str());
   }
+  catch(const ExceptionConnection& ex)
+  {
+    // Remember port if only the database was missing
+    bool connection_possible = false;
+    if(ex.get_failure_type() == ExceptionConnection::FAILURE_NO_DATABASE)
+    {
+      connection_possible = true;
+      m_port = atoi(port.c_str());
+    }
+  }
 
   // Try more ports if so desired, and we don't have a connection yet
   if(m_try_other_ports && !connection)
@@ -128,14 +117,23 @@ Glib::RefPtr<Gnome::Gda::Connection> PostgresCentralHosted::connect(const Glib::
     while(!connection && iter_port != m_list_ports.end())
     {
       port = *iter_port;
-      connection = attempt_connect(m_host, port, database, username, password, error);
 
-      // Remember port if only the database was missing
-      if(error.get() && error->get_failure_type() == ExceptionConnection::FAILURE_NO_DATABASE)
+      try
       {
+        connection = attempt_connect(port, database, username, password);
         connection_possible = true;
         m_port = atoi(port.c_str());
       }
+      catch(const ExceptionConnection& ex)
+      {
+        connection_possible = false;
+        // Remember port if only the database was missing
+        if(ex.get_failure_type() == ExceptionConnection::FAILURE_NO_DATABASE)
+        {
+          connection_possible = true;
+          m_port = atoi(port.c_str());
+        }
+      }
 
       // Skip if we already tried this port
       if(iter_port != m_list_ports.end() && *iter_port == port)
@@ -151,20 +149,18 @@ Glib::RefPtr<Gnome::Gda::Connection> PostgresCentralHosted::connect(const Glib::
   else
   {
     if(connection_possible)
-      error.reset(new ExceptionConnection(ExceptionConnection::FAILURE_NO_DATABASE));
+      throw ExceptionConnection(ExceptionConnection::FAILURE_NO_DATABASE);
     else
-      error.reset(new ExceptionConnection(ExceptionConnection::FAILURE_NO_SERVER));
+      throw ExceptionConnection(ExceptionConnection::FAILURE_NO_SERVER);
   }
 
   return connection;
 }
 
-#ifndef GLOM_ENABLE_CLIENT_ONLY
-bool PostgresCentralHosted::create_database(const Glib::ustring& database_name, const Glib::ustring& username, const Glib::ustring& password, std::auto_ptr<Glib::Error>& error)
+bool PostgresCentralHosted::create_database(const Glib::ustring& database_name, const Glib::ustring& username, const Glib::ustring& password)
 {
-  return attempt_create_database(database_name, get_host(), port_as_string(m_port), username, password, error);
+  return attempt_create_database(database_name, get_host(), port_as_string(m_port), username, password);
 }
-#endif //GLOM_ENABLE_CLIENT_ONLY
 
 }
 
