@@ -16,10 +16,10 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include <config.h>
+#include "config.h"
 #include <libglom/document/bakery/document.h>
 #include <giomm.h>
-//#include <fstream>
+#include <iostream>
 #include <glibmm/i18n-lib.h>
 
 namespace GlomBakery
@@ -210,14 +210,13 @@ bool Document::read_from_disk(int& failure_code)
 
   Glib::RefPtr<Gio::FileInputStream> stream;
 
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
     stream = file->read();
   }
   catch(const Gio::Error& ex)
   {
-    std::cout << "Debug: Document::read_from_disk(): Error: " << ex.what() << std::endl;
+    std::cout << "debug: " << G_STRFUNC << ": Error: " << ex.what() << std::endl;
 
     if(ex.code() == Gio::Error::NOT_FOUND)
       failure_code = LOAD_FAILURE_CODE_NOT_FOUND;
@@ -226,32 +225,18 @@ bool Document::read_from_disk(int& failure_code)
     // If the operation was not successful, print the error and abort
     return false; //print_error(ex, input_uri_string);
   }
-#else
-  std::auto_ptr<Glib::Error> error;
-  stream = file->read(error);
-  if(error.get())
-    return false; //print_error(ex, input_uri_string);
-#endif
 
   // Read data from the input uri:
   guint buffer[BYTES_TO_PROCESS] = {0, }; // For each chunk.
   gsize bytes_read = 0;
   std::string data; //We use a std::string because we might not get whole UTF8 characters at a time. This might not be necessary.
 
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
-#endif
   {
     bool bContinue = true;
     while(bContinue)
     {
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
       bytes_read = stream->read(buffer, BYTES_TO_PROCESS);
-#else
-      std::auto_ptr<Glib::Error> gerror;
-      bytes_read = stream->read(buffer, BYTES_TO_PROCESS, gerror);
-      if(gerror.get()) break;
-#endif
 
       if(bytes_read == 0)
         bContinue = false; //stop because we reached the end.
@@ -262,14 +247,8 @@ bool Document::read_from_disk(int& failure_code)
       }
     }
   }
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
   catch(const Gio::Error& ex)
   {
-#else
-  if(error.get())
-  {
-    std::cerr << "Bakery::Document::read_from_disk(): Error: " << error->what() << std::endl;
-#endif
     // If the operation was not successful, print the error and abort
     return false; //print_error(ex, input_uri_string);
   }
@@ -301,7 +280,7 @@ bool Document::write_to_disk()
       }
       catch(const Gio::Error& ex)
       {
-        std::cerr << "Bakery::Document::write_to_disk(): Error from Gio::File::replace(): " << ex.what() << std::endl;
+        std::cerr << G_STRFUNC << ": " << ex.what() << std::endl;
         return false;
       }
     }
@@ -311,7 +290,8 @@ bool Document::write_to_disk()
       Glib::RefPtr<Gio::File> parent = file->get_parent();
       try
       {
-        parent->make_directory_with_parents();
+        if(parent) //It will be empty if file was the root node of the filesystem.
+          parent->make_directory_with_parents();
       }
       catch(const Gio::Error& ex)
       {
@@ -319,7 +299,7 @@ bool Document::write_to_disk()
         //Otherwise something unexpected happened.
         if(ex.code() != Gio::Error::EXISTS)
         {
-          std::cerr << "Bakery::Document::write_to_disk(): Error from Gio::File::make_directory_with_parents(): parent of uri=" << m_file_uri << "error=" << ex.what() << std::endl;
+          std::cerr << G_STRFUNC << ": parent of uri=" << m_file_uri << "error=" << ex.what() << std::endl;
           return false;
         }
       }
@@ -334,7 +314,7 @@ bool Document::write_to_disk()
       }
       catch(const Gio::Error& ex)
       {
-        std::cerr << "Bakery::Document::write_to_disk(): Error from Gio::File::create_file():" << m_file_uri << "error=" << ex.what() << std::endl;
+        std::cerr << G_STRFUNC << ":" << m_file_uri << "error=" << ex.what() << std::endl;
         return false;
       }
     }
@@ -343,7 +323,6 @@ bool Document::write_to_disk()
       return false;
 
 
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
     try
     {
       //Write the data to the output uri
@@ -356,15 +335,8 @@ bool Document::write_to_disk()
     }
     catch(const Gio::Error& ex)
     {
-#else
-    std::auto_ptr<Glib::Error> gerror;
-    stream->write(m_strContents.data(), m_strContents.bytes(), gerror);
-    if(gerror.get())
-    {
-      std::cerr << "akery::Document::write_to_disk(): Error from Gio stream.write(): "<< gerror.get() << std::endl;
-#endif
       // If the operation was not successful, print the error and abort
-      std::cerr << "Bakery::Document::write_to_disk(): Error from Gio stream.write(): " << ex.what() << std::endl;
+      std::cerr << G_STRFUNC << ": " << ex.what() << std::endl;
       return false; //print_error(ex, output_uri_string);
     }
 
@@ -390,7 +362,6 @@ static Glib::ustring get_file_display_name(const Glib::ustring& uri)
   Glib::RefPtr<Gio::File> file = Gio::File::create_for_uri(uri);
   Glib::RefPtr<const Gio::FileInfo> file_info;
 
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
     file_info = file->query_info(G_FILE_ATTRIBUTE_STANDARD_DISPLAY_NAME);
@@ -400,12 +371,6 @@ static Glib::ustring get_file_display_name(const Glib::ustring& uri)
     std::cerr << "Application::get_file_display_name(uri=" << uri << "): error: " << ex.what() << std::endl;
     return result;
   }
-#else
-  std::auto_ptr<Gio::Error> error;
-  file_info = uri->query_info(G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE, Gio::FILE_QUERY_INFO_NONE, error);
-  if(error.get())
-    return result;
-#endif
 
   if(!file_info)
     return result;
@@ -466,7 +431,6 @@ bool Document::get_read_only() const
     {
       Glib::RefPtr<Gio::File> file = Gio::File::create_for_uri(m_file_uri);
       Glib::RefPtr<Gio::FileInfo> info;
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
       try
       {
         Glib::RefPtr<Gio::FileInfo> info = file->query_info(G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE);
@@ -475,12 +439,6 @@ bool Document::get_read_only() const
       {
         return false; //We should at least be able to read the permissions, so maybe the location is invalid. I'm not sure what the best return result here is.
       }
-#else
-      std::auto_ptr<Glib::Error> error;
-      info = file->query_info(G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE, Gio::FILE_QUERY_INFO_NONE, error);
-      if(error.get())
-        return false;
-#endif
 
       if(!info)
         return false;
