@@ -24,6 +24,8 @@
 #include <libglom/utils.h>
 //#include <glom/application.h>
 
+#include <iostream>
+
 namespace Glom
 {
 
@@ -46,12 +48,7 @@ Privs::type_vec_strings Privs::get_database_groups()
     const int rows_count = data_model->get_n_rows();
     for(int row = 0; row < rows_count; ++row)
     {
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
       const Gnome::Gda::Value value = data_model->get_value_at(0, row);
-#else
-      std::auto_ptr<Glib::Error> value_error;
-      const Gnome::Gda::Value value = data_model->get_value_at(0, row, value_error);
-#endif
       const Glib::ustring name = value.get_string();
       result.push_back(name);
     }
@@ -118,12 +115,7 @@ Privs::type_vec_strings Privs::get_database_users(const Glib::ustring& group_nam
       const int rows_count = data_model->get_n_rows();
       for(int row = 0; row < rows_count; ++row)
       {
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
         const Gnome::Gda::Value value = data_model->get_value_at(0, row);
-#else
-        std::auto_ptr<Glib::Error> value_error;
-        const Gnome::Gda::Value value = data_model->get_value_at(0, row, value_error);
-#endif
         const Glib::ustring name = value.get_string();
         result.push_back(name);
       }
@@ -146,12 +138,7 @@ Privs::type_vec_strings Privs::get_database_users(const Glib::ustring& group_nam
       const int rows_count = data_model->get_n_rows();
       for(int row = 0; row < rows_count; ++row)
       {
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
         const Gnome::Gda::Value value = data_model->get_value_at(1, row); //Column 1 is the /* the user list.
-#else
-        std::auto_ptr<Glib::Error> value_error;
-        const Gnome::Gda::Value value = data_model->get_value_at(1, row, value_error); //Column 1 is the /* the user list.
-#endif
         //pg_group is a string, formatted, bizarrely, like so: "{100, 101}".
 
         Glib::ustring group_list;
@@ -171,16 +158,15 @@ Privs::type_vec_strings Privs::get_database_users(const Glib::ustring& group_nam
               builder->add_field_id("usesysid", "pg_user"),
               builder->add_expr(*iter)));
           Glib::RefPtr<Gnome::Gda::DataModel> data_model = DbUtils::query_execute_select(builder);
-          if(data_model)
+          if(data_model && data_model->get_n_rows() && data_model->get_n_columns())
           {
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
             const Gnome::Gda::Value value = data_model->get_value_at(0, 0);
-#else
-            std::auto_ptr<Glib::Error> value_error;
-            const Gnome::Gda::Value value = data_model->get_value_at(0, 0, value_error);
-#endif
             result.push_back(value.get_string());
           }
+          else
+          {
+            std::cerr << G_STRFUNC << ": user not found in pg_user table: " << *iter << std::endl;
+          }
         }
 
       }
@@ -248,7 +234,7 @@ void Privs::set_table_privileges(const Glib::ustring& group_name, const Glib::us
 
   const bool test = DbUtils::query_execute_string(strQuery);
   if(!test)
-    std::cerr << "Privs::set_table_privileges(): GRANT failed." << std::endl;
+    std::cerr << G_STRFUNC << ": GRANT failed." << std::endl;
   else
   {
     if( (table_name != GLOM_STANDARD_TABLE_AUTOINCREMENTS_TABLE_NAME) && privs.m_create )
@@ -289,12 +275,7 @@ Privileges Privs::get_table_privileges(const Glib::ustring& group_name, const Gl
   Glib::RefPtr<Gnome::Gda::DataModel> data_model = DbUtils::query_execute_select(builder);
   if(data_model && data_model->get_n_rows())
   {
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
     const Gnome::Gda::Value value = data_model->get_value_at(0, 0);
-#else
-    std::auto_ptr<Glib::Error> value_error;
-    const Gnome::Gda::Value value = data_model->get_value_at(0, 0, value_error);
-#endif
 
     Glib::ustring access_details;
     if(!value.is_null())
@@ -420,13 +401,13 @@ bool Privs::get_user_is_in_group(const Glib::ustring& user, const Glib::ustring&
 
 bool Privs::on_privs_privileges_cache_timeout(const Glib::ustring& table_name)
 {
-  //std::cout << "DEBUG: Privs::on_privs_privileges_cache_timeou(): table=" << table_name << std::endl;
+  //std::cout << "debug: " << G_STRFUNC << ": table=" << table_name << std::endl;
 
   //Forget the cached privileges after a few seconds:
   type_map_privileges::iterator iter = m_privileges_cache.find(table_name);
   if(iter != m_privileges_cache.end())
   {
-    //std::cout << "  DEBUG: Privs::on_privs_privileges_cache_timeou(): Cleared cache for table=" << table_name << std::endl;
+    //std::cout << "debug: " << G_STRFUNC << ": Cleared cache for table=" << table_name << std::endl;
     m_privileges_cache.erase(iter);
   }
 
@@ -445,7 +426,7 @@ Privileges Privs::get_current_privs(const Glib::ustring& table_name)
   type_map_privileges::const_iterator iter = m_privileges_cache.find(table_name);
   if(iter != m_privileges_cache.end())
   {
-    //std::cout << "DEBUG: Privs::get_current_privs(): Returning cache." << std::endl;
+    //std::cout << "debug: " << G_STRFUNC << ": Returning cache." << std::endl;
     return iter->second;
   }
 
@@ -453,7 +434,7 @@ Privileges Privs::get_current_privs(const Glib::ustring& table_name)
   //Get the up-to-date privileges from the database:
   Privileges result;
 
-  //std::cout << "DEBUG: Privs::get_current_privs(): Getting non-cached." << std::endl;
+  //std::cout << "debug: " << G_STRFUNC << ": Getting non-cached." << std::endl;
 
   ConnectionPool* connection_pool = ConnectionPool::get_instance();
   const Glib::ustring current_user = connection_pool->get_user();
@@ -467,12 +448,7 @@ Privileges Privs::get_current_privs(const Glib::ustring& table_name)
     result.m_developer = true;
   }
   */
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
   sharedptr<SharedConnection> sharedconnection = connection_pool->connect();
-#else
-  std::auto_ptr<ExceptionConnection> ex;
-  sharedptr<SharedConnection> sharedconnection = connection_pool->connect(ex);
-#endif
   if(sharedconnection && sharedconnection->get_gda_connection()->supports_feature(Gnome::Gda::CONNECTION_FEATURE_USERS))
   {
     //Get the "true" rights for any groups that the user is in:
