@@ -24,10 +24,11 @@
 #include <libglom/data_structure/field.h>
 #include <libglom/data_structure/relationship.h>
 #include <libglom/data_structure/glomconversions.h>
+#include <libglom/db_utils.h>
 #include <glom/mode_design/layout/dialog_layout_details.h>
 #include <glom/glade_utils.h>
 #include <glom/utils_ui.h>
-#include <glom/glom_privs.h>
+#include <libglom/privs.h>
 #include <glom/xsl_utils.h>
 #include <glom/python_embed/glom_python.h>
 #include <sstream> //For stringstream
@@ -39,7 +40,7 @@ namespace Glom
 Box_Data_Details::Box_Data_Details(bool bWithNavButtons /* = true */)
 : m_hbox_content(false, Utils::DEFAULT_SPACING_SMALL),
 #ifndef GLOM_ENABLE_MAEMO
-  m_hbox_buttons(false, Utils::DEFAULT_SPACING_SMALL),
+  m_hbox_buttons(Gtk::BUTTONBOX_END, Utils::DEFAULT_SPACING_SMALL),
   m_Button_New(Gtk::Stock::ADD),
   m_Button_Del(Gtk::Stock::DELETE),
   m_Button_Nav_First(Gtk::Stock::GOTO_FIRST),
@@ -127,6 +128,9 @@ Box_Data_Details::Box_Data_Details(bool bWithNavButtons /* = true */)
   m_hbox_buttons.pack_start(m_Button_New, Gtk::PACK_SHRINK);
   m_hbox_buttons.pack_start(m_Button_Del,  Gtk::PACK_SHRINK);
 
+  m_hbox_buttons.set_child_secondary(m_Button_New, true);
+  m_hbox_buttons.set_child_secondary(m_Button_Del, true);
+
   //Link buttons to handlers:
   m_Button_New.signal_clicked().connect(sigc::mem_fun(*this, &Box_Data_Details::on_button_new));
   m_Button_Del.signal_clicked().connect(sigc::mem_fun(*this, &Box_Data_Details::on_button_del));
@@ -134,10 +138,10 @@ Box_Data_Details::Box_Data_Details(bool bWithNavButtons /* = true */)
   //Navigation:
   if(bWithNavButtons)
   {
-    m_hbox_buttons.pack_end(m_Button_Nav_Last, Gtk::PACK_SHRINK);
-    m_hbox_buttons.pack_end(m_Button_Nav_Next, Gtk::PACK_SHRINK);
-    m_hbox_buttons.pack_end(m_Button_Nav_Prev, Gtk::PACK_SHRINK);
-    m_hbox_buttons.pack_end(m_Button_Nav_First, Gtk::PACK_SHRINK);
+    m_hbox_buttons.pack_start(m_Button_Nav_First, Gtk::PACK_SHRINK);
+    m_hbox_buttons.pack_start(m_Button_Nav_Prev, Gtk::PACK_SHRINK);
+    m_hbox_buttons.pack_start(m_Button_Nav_Next, Gtk::PACK_SHRINK);
+    m_hbox_buttons.pack_start(m_Button_Nav_Last, Gtk::PACK_SHRINK);
   }
 
   //Link buttons to handlers:
@@ -175,16 +179,15 @@ void Box_Data_Details::set_found_set_from_primary_key_value()
 
   if(!m_primary_key_value.is_null())
   {
-    //TODO: Use a SQL parameter instead of using sql().
-    m_found_set.m_where_clause = "\"" + m_table_name + "\".\"" + m_field_primary_key->get_name() +
-      "\" = " + m_field_primary_key->sql(m_primary_key_value);
-    //std::cout << "  DEBUG: Box_Data_Details::set_primary_key_value(): m_found_set.m_where_clause = " << m_found_set.m_where_clause << std::endl;
+    m_found_set.m_where_clause = Utils::build_simple_where_expression(
+       m_table_name, m_field_primary_key, m_primary_key_value);
+    //std::cout << "debug: " << G_STRFUNC << ": m_found_set.m_where_clause = " << m_found_set.m_where_clause << std::endl;
   }
 }
 
 bool Box_Data_Details::init_db_details(const FoundSet& found_set, const Glib::ustring& layout_platform, const Gnome::Gda::Value& primary_key_value)
 {
-  //std::cout << "Box_Data_Details::init_db_details(): primary_key_value=" << primary_key_value.to_string() << std::endl;
+  //std::cout << "debug: " << G_STRFUNC << ": primary_key_value=" << primary_key_value.to_string() << std::endl;
 
   m_primary_key_value = primary_key_value;
   m_field_primary_key = get_field_primary_key_for_table(found_set.m_table_name);
@@ -242,7 +245,7 @@ void Box_Data_Details::create_layout()
 
 bool Box_Data_Details::fill_from_database()
 {
-  //std::cout << "Box_Data_Details::fill_from_database(): m_primary_key_value=" << m_primary_key_value.to_string() << std::endl;
+  //std::cout << "debug: " << G_STRFUNC << ": m_primary_key_value=" << m_primary_key_value.to_string() << std::endl;
 
   //Don't try to open a connection if there is no document,
   //for instance, during application destruction.
@@ -267,7 +270,6 @@ bool Box_Data_Details::fill_from_database()
   //reconnect many times..
   sharedptr<SharedConnection> sharedconnection;
 
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
     sharedconnection = connect_to_server(get_app_window());
@@ -282,15 +284,6 @@ bool Box_Data_Details::fill_from_database()
     handle_error(ex);
     bResult = false;
   }
-#else
-  std::auto_ptr<ExceptionConnection> error;
-  sharedconnection = connect_to_server(get_app_window(), error);
-  if(error.get())
-  {
-    handle_error(*error);
-    bResult = false;
-  }
-#endif
 
   if(sharedconnection)
   {
@@ -298,7 +291,7 @@ bool Box_Data_Details::fill_from_database()
     bResult = Box_Data::fill_from_database();
 
     m_FieldsShown = get_fields_to_show();
-    type_vecLayoutFields fieldsToGet = m_FieldsShown;
+    type_vecConstLayoutFields fieldsToGet = m_FieldsShown;
 
     if(!fieldsToGet.empty())
     {
@@ -321,7 +314,7 @@ bool Box_Data_Details::fill_from_database()
         //TODO_Performance: Do this for create_layout() only, instead of repeating it for each refresh?:
         int index_primary_key = -1; //Arbitrary default.
         //g_warning("primary_key name = %s", m_field_primary_key->get_name().c_str());
-        const type_vecLayoutFields::const_iterator iterFind = std::find_if(fieldsToGet.begin(), fieldsToGet.end(), predicate_LayoutItem_Field_IsSameField<LayoutItem_Field>(layout_item));
+        const type_vecConstLayoutFields::const_iterator iterFind = std::find_if(fieldsToGet.begin(), fieldsToGet.end(), predicate_LayoutItem_Field_IsSameField<LayoutItem_Field>(layout_item));
         if(iterFind == fieldsToGet.end())
         {
           fieldsToGet.push_back(layout_item);
@@ -352,11 +345,11 @@ bool Box_Data_Details::fill_from_database()
           }
         }
 
-        const Glib::ustring query = Utils::build_sql_select_with_key(m_table_name, fieldsToGet, m_field_primary_key, m_primary_key_value);
+        Glib::RefPtr<Gnome::Gda::SqlBuilder> query = Utils::build_sql_select_with_key(m_table_name, fieldsToGet, m_field_primary_key, m_primary_key_value);
         Glib::RefPtr<Gnome::Gda::DataModel> result;
 
         if(!primary_key_is_empty)
-          result = query_execute_select(query);
+          result = DbUtils::query_execute_select(query);
 
         if((result && result->get_n_rows()) || primary_key_is_empty) //either a working result or no result needed.
         {
@@ -378,14 +371,7 @@ bool Box_Data_Details::fill_from_database()
             {
               if(index_primary_key < cols_count)
               {
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
                 m_primary_key_value = result->get_value_at(index_primary_key, row_number);
-#else
-              {
-                std::auto_ptr<Glib::Error> value_error;
-                m_primary_key_value = result->get_value_at(index_primary_key, row_number, value_error);
-              }
-#endif
                 set_found_set_from_primary_key_value();
               }
             }
@@ -393,20 +379,13 @@ bool Box_Data_Details::fill_from_database()
             //Get field values to show:
             for(int i = 0; i < cols_count; ++i)
             {
-              sharedptr<LayoutItem_Field> layout_item = fieldsToGet[i];
+              sharedptr<const LayoutItem_Field> layout_item = fieldsToGet[i];
 
               //Field value:
               Gnome::Gda::Value value;
 
               if(!primary_key_is_empty)
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
                 value = result->get_value_at(i, row_number);
-#else
-              {
-                std::auto_ptr<Glib::Error> value_error;
-                value = result->get_value_at(i, row_number, value_error);
-              }
-#endif
               else
               {
                 value = Conversions::get_empty_value(layout_item->get_glom_type());
@@ -455,7 +434,7 @@ void Box_Data_Details::on_button_new()
   if(m_field_primary_key && m_field_primary_key->get_auto_increment()) //If the primary key is an auto-increment:
   {
     //Just make a new record, and show it:
-    Gnome::Gda::Value primary_key_value = get_next_auto_increment_value(m_table_name, m_field_primary_key->get_name()); //TODO: This should return a Gda::Value
+    const Gnome::Gda::Value primary_key_value = DbUtils::get_next_auto_increment_value(m_table_name, m_field_primary_key->get_name()); //TODO: This should return a Gda::Value
 
     record_new(false /* use entered field data */, primary_key_value);
     refresh_data_from_database_with_primary_key(primary_key_value);
@@ -583,7 +562,7 @@ void Box_Data_Details::on_related_record_added(Gnome::Gda::Value /* strKeyValue
   bool bDoNotRefreshRelated = m_bDoNotRefreshRelated;
   m_bDoNotRefreshRelated = true;
 
-  //std::cout << "Box_Data_Details::on_related_record_added(): " << strKeyValue << ", " << strFromKeyName << std::endl;
+  //std::cout << "debug: " << G_STRFUNC << ": " << strKeyValue << ", " << strFromKeyName << std::endl;
   //Get current FromKey value:
 
  /* TODO_port
@@ -743,7 +722,7 @@ void Box_Data_Details::on_flowtable_field_edited(const sharedptr<const LayoutIte
   Document* document = dynamic_cast<Document*>(get_document());
 
   Gnome::Gda::Value primary_key_value = get_primary_key_value_selected();
-  //std::cout << "Box_Data_Details::on_flowtable_field_edited(): primary_key_value=" << primary_key_value.to_string() << std::endl;
+  //std::cout << "debug: " << G_STRFUNC << ": primary_key_value=" << primary_key_value.to_string() << std::endl;
   if(!Conversions::value_is_empty(primary_key_value)) //If there is not a primary key value:
   {
     Glib::ustring table_name;
@@ -815,13 +794,10 @@ void Box_Data_Details::on_flowtable_field_edited(const sharedptr<const LayoutIte
     //Update the field in the record (the record with this primary key):
 
     bool bTest = false;
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
     try
-#endif // GLIBMM_EXCEPTIONS_ENABLED
     {
       bTest = set_field_value_in_database(field_in_record, field_value, false /* don't use current calculations */, get_app_window());
     }
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
     catch(const Glib::Exception& ex)
     {
       handle_error(ex);
@@ -830,11 +806,8 @@ void Box_Data_Details::on_flowtable_field_edited(const sharedptr<const LayoutIte
     {
       handle_error(ex);
     }
-#endif // GLIBMM_EXCEPTIONS_ENABLED
 
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
     try
-#endif // GLIBMM_EXCEPTIONS_ENABLED
     {
       if(!bTest)
       {
@@ -868,7 +841,6 @@ void Box_Data_Details::on_flowtable_field_edited(const sharedptr<const LayoutIte
       }
 
     }
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
     catch(const Glib::Exception& ex)
     {
       handle_error(ex);
@@ -877,7 +849,6 @@ void Box_Data_Details::on_flowtable_field_edited(const sharedptr<const LayoutIte
     {
       handle_error(ex);
     }
-#endif // GLIBMM_EXCEPTIONS_ENABLED
   }
   else
   {
@@ -896,7 +867,7 @@ void Box_Data_Details::on_flowtable_field_edited(const sharedptr<const LayoutIte
       else
       {
         //Make a new record, and show it:
-        Gnome::Gda::Value primary_key_value = get_next_auto_increment_value(m_table_name, m_field_primary_key->get_name());
+        const Gnome::Gda::Value primary_key_value = DbUtils::get_next_auto_increment_value(m_table_name, m_field_primary_key->get_name());
 
         record_new(true /* use entered field data */, primary_key_value);
         refresh_data_from_database_with_primary_key(primary_key_value);
@@ -1048,15 +1019,9 @@ void Box_Data_Details::print_layout()
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 Dialog_Layout* Box_Data_Details::create_layout_dialog() const
 {
-  Glib::RefPtr<Gtk::Builder> refXml = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom_developer.glade"), "window_data_layout"); //TODO: Use a generic layout dialog?
-  if(refXml)
-  {
-    Dialog_Layout_Details* dialog = 0;
-    refXml->get_widget_derived("window_data_layout", dialog);
-    return dialog;
-  }
-
-  return 0;
+  Dialog_Layout_Details* dialog = 0;
+  Glom::Utils::get_glade_widget_derived_with_warning(dialog);
+  return dialog;
 }
 
 void Box_Data_Details::prepare_layout_dialog(Dialog_Layout* dialog)
