@@ -29,6 +29,9 @@
 namespace Glom
 {
 
+const char* Dialog_FieldDefinition::glade_id("window_field_definition_edit");
+const bool Dialog_FieldDefinition::glade_developer(true);
+
 Dialog_FieldDefinition::Dialog_FieldDefinition(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
 : Dialog_Properties(cobject, builder),
   m_pDataWidget_DefaultValueSimple(0),
@@ -42,7 +45,7 @@ Dialog_FieldDefinition::Dialog_FieldDefinition(BaseObjectType* cobject, const Gl
 
   builder->get_widget("checkbutton_unique",  m_pCheck_Unique);
   builder->get_widget("checkbutton_primarykey",  m_pCheck_PrimaryKey);
-  builder->get_widget("checkbutton_autoincrement",  m_pCheck_AutoIncrement);  
+  builder->get_widget("checkbutton_autoincrement",  m_pCheck_AutoIncrement);
 
   builder->get_widget("hbox_default_value_simple",  m_pBox_DefaultValueSimple);
 
@@ -84,24 +87,24 @@ Dialog_FieldDefinition::Dialog_FieldDefinition(BaseObjectType* cobject, const Gl
   builder->get_widget("box_formatting_placeholder", m_box_formatting_placeholder);
 
   //Get the formatting stuff:
-  try
-  {
-    Glib::RefPtr<Gtk::Builder> refXmlFormatting = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom_developer.glade"), "box_formatting");
-    refXmlFormatting->get_widget_derived("box_formatting", m_box_formatting);
-  }
-  catch(const Gtk::BuilderError& ex)
-  {
-    std::cerr << ex.what() << std::endl;
-  }
+  Utils::get_glade_widget_derived_with_warning(m_box_formatting);
+
+  if(m_box_formatting) ////Unlikely to fail and it already warns on stderr.
+    m_box_formatting_placeholder->pack_start(*m_box_formatting);
 
-  m_box_formatting_placeholder->pack_start(*m_box_formatting);
   add_view(m_box_formatting);
 
 
   on_foreach_connect(*this);
   on_foreach_connect(*m_pBox_DefaultValueSimple);
   on_foreach_connect(*m_pBox_ValueTab);
-  on_foreach_connect(*m_box_formatting);
+
+  if(m_box_formatting) ////Unlikely to fail and it already warns on stderr.
+    on_foreach_connect(*m_box_formatting);
+
+  //Plus an extra signal for the related extra show-also fields:
+  m_box_formatting->signal_modified().connect(
+   sigc::mem_fun(*this, &Dialog_FieldDefinition::on_anything_changed));
 
   Dialog_Properties::set_modified(false);
 
@@ -157,13 +160,16 @@ void Dialog_FieldDefinition::set_field(const sharedptr<const Field>& field, cons
   field_default_value->set_title(_("Default Value"));
   layout_item->set_full_field_details(field_default_value);
   m_pDataWidget_DefaultValueSimple = Gtk::manage( new DataWidget(layout_item, "", get_document()) );
+  if(!m_pDataWidget_DefaultValueSimple->get_data_child_widget())
+    std::cerr << G_STRFUNC << ": The DataWidget did not create a child widget." << std::endl;
+
   on_foreach_connect(*m_pDataWidget_DefaultValueSimple);
 
   Gtk::Label* pLabel = m_pDataWidget_DefaultValueSimple->get_label();
   if(!pLabel->get_text().empty())
     m_pBox_DefaultValueSimple->pack_start(*pLabel);
 
-  m_pBox_DefaultValueSimple->pack_end(*m_pDataWidget_DefaultValueSimple, Gtk::PACK_EXPAND_WIDGET); 
+  m_pBox_DefaultValueSimple->pack_end(*m_pDataWidget_DefaultValueSimple, Gtk::PACK_EXPAND_WIDGET);
   m_pDataWidget_DefaultValueSimple->set_value(default_value);
   m_pDataWidget_DefaultValueSimple->show();
 
@@ -209,7 +215,7 @@ void Dialog_FieldDefinition::set_field(const sharedptr<const Field>& field, cons
   m_pEntry_Title->set_text(field->get_title());
 
   //Formatting:
-  m_box_formatting->set_formatting(field->m_default_formatting, m_table_name, field);
+  m_box_formatting->set_formatting_for_field(field->m_default_formatting, m_table_name, field);
 
   set_blocked(false);
 
@@ -223,7 +229,7 @@ sharedptr<Field> Dialog_FieldDefinition::get_field() const
   // const_cast is necessary and save here for the window (jhs)
   sharedptr<SharedConnection> sharedcnc = connect_to_server(const_cast<Dialog_FieldDefinition*>(this));
   Glib::RefPtr<Gnome::Gda::Connection> cnc = sharedcnc->get_gda_connection();
-  
+
   //Get the field info from the widgets:
 
   Glib::RefPtr<Gnome::Gda::Column> fieldInfo = field->get_field_info(); //Preserve previous information.
@@ -345,7 +351,7 @@ void Dialog_FieldDefinition::on_combo_lookup_relationship_changed()
 {
   //Get the fields that are avaiable from the new relationship:
 
-  m_pCombo_LookupField->clear_items();
+  m_pCombo_LookupField->remove_all();
 
   //Get the relationship name:
   sharedptr<const Relationship> relationship = m_pCombo_LookupRelationship->get_selected_relationship();
@@ -373,31 +379,24 @@ void Dialog_FieldDefinition::on_combo_lookup_relationship_changed()
 void Dialog_FieldDefinition::on_button_edit_calculation()
 {
   //TODO: Share a global instance, to make this quicker?
-  Glib::RefPtr<Gtk::Builder> refXml = Gtk::Builder::create_from_file(GLOM_GLADEDIR "glom_developer.glade", "window_field_calculation");
-  if(refXml)
+  Dialog_FieldCalculation* dialog = 0;
+  Utils::get_glade_widget_derived_with_warning(dialog);
+  if(!dialog) //Unlikely and it already warns on stderr.
+    return;
+
+  add_view(dialog); //Give it access to the document.
+
+  m_Field->set_calculation( m_pTextView_Calculation->get_buffer()->get_text() );
+  dialog->set_field(m_Field, m_table_name);
+  //TODO: dialog.set_transient_for(*get_app_window());
+  const int response = Glom::Utils::dialog_run_with_help(dialog);
+  if(response == Gtk::RESPONSE_OK)
   {
-    Dialog_FieldCalculation* dialog = 0;
-    refXml->get_widget_derived("window_field_calculation", dialog);
-    if(dialog)
-    {
-      add_view(dialog); //Give it access to the document.
-
-      m_Field->set_calculation( m_pTextView_Calculation->get_buffer()->get_text() );
-      dialog->set_field(m_Field, m_table_name);
-      //TODO: dialog.set_transient_for(*get_app_window());
-      const int response = Glom::Utils::dialog_run_with_help(dialog, "window_field_calculation");
-      if(response == Gtk::RESPONSE_OK)
-      {
-        m_pTextView_Calculation->get_buffer()->set_text( dialog->get_field()->get_calculation() );
-      }
-
-      remove_view(dialog);
-      delete dialog;
-    }
+    m_pTextView_Calculation->get_buffer()->set_text( dialog->get_field()->get_calculation() );
   }
+
+  remove_view(dialog);
+  delete dialog;
 }
 
 } //namespace Glom
-
-
-
