@@ -94,6 +94,9 @@ void Dialog_ScriptLibrary::on_button_add()
 
   Dialog_NewScript* dialog = 0;
   Utils::get_glade_widget_derived_with_warning(dialog);
+  if(!dialog) //Unlikely and it already warns on stderr.
+    return;
+    
   dialog->set_transient_for(*this);
   const int response = Glom::Utils::dialog_run_with_help(dialog);
   dialog->hide();
@@ -199,7 +202,7 @@ void Dialog_ScriptLibrary::load_from_document()
     return;
 
   const std::vector<Glib::ustring> module_names = document->get_library_module_names();
-  m_combobox_name->clear_items();
+  m_combobox_name->remove_all();
  
   for(std::vector<Glib::ustring>::const_iterator iter = module_names.begin(); iter != module_names.end(); ++iter)
   {
